@@ -3,7 +3,6 @@ import logging
 from types import GeneratorType
 
 import pytest
-from bs4 import BeautifulSoup
 from pypuppetdb.errors import EmptyResponseError
 from requests import Response
 from requests.exceptions import ConnectionError, HTTPError
@@ -16,10 +15,34 @@ from puppetboard import utils
 def test_json_format():
     demo = [{'foo': 'bar'}, {'bar': 'foo'}]
     sample = json.dumps(demo, indent=2, separators=(',', ': '))
-
     assert sample == utils.jsonprint(demo), "Json formatting has changed"
 
 
+def test_parse_python_array():
+    python_array = [{'foo': 'bar'}, {'bar': 'foo'}]
+    python_array_as_string = str(python_array)
+    assert python_array == utils.parse_python(python_array_as_string)
+
+
+def test_parse_python_not_really_array():
+    # the downside of simplifying showing plain strings without quotes is that it's hard
+    # to distinguish things that LOOK LIKE non-string but in fact are strings.
+    python_not_really_array = '"["foo", "bar"]"'
+    python_not_really_array_as_string = '"["foo", "bar"]"'
+    assert python_not_really_array == utils.parse_python(python_not_really_array_as_string)
+
+
+def test_parse_python_dict():
+    python_dict = {'foo': 'bar'}
+    python_dict_as_string = str(python_dict)
+    assert python_dict == utils.parse_python(python_dict_as_string)
+
+
+def test_parse_python_string():
+    a_string = "foobar"
+    assert a_string == utils.parse_python(a_string)
+
+
 def test_format_val_str():
     x = "some string"
     assert x == utils.formatvalue(x), "Should return same value"
@@ -49,15 +72,6 @@ def test_get():
     assert x == utils.get_or_abort(test_get_or_abort)
 
 
-def test_pretty_print():
-    test_data = [{'hello': 'world'}]
-
-    html = utils.prettyprint(test_data)
-    soup = BeautifulSoup(html, 'html.parser')
-
-    assert soup.th.text == 'hello'
-
-
 @pytest.fixture
 def mock_log(mocker):
     return mocker.patch('logging.log')
@@ -89,6 +103,20 @@ def test_http_error(mock_log):
         mock_log.error.assert_called_once_with(err)
 
 
+def test_http_error_reraised_as_client_side(mock_log):
+    err = "The request is invalid because ..."
+
+    def raise_http_400_error():
+        x = Response()
+        x.status_code = 400
+        x.reason = err
+        raise HTTPError(err, response=x)
+
+    with pytest.raises(HTTPError):
+        utils.get_or_abort_except_client_errors(raise_http_400_error)
+        mock_log.warning.assert_called_once_with(err)
+
+
 def test_http_connection_error(mock_log):
     err = "ConnectionError"
 
@@ -117,26 +145,35 @@ def test_basic_exception(mock_log):
         assert exception.status_code == 500
 
 
-def test_db_version_good(mocker, mock_info_log):
-    mocker.patch.object(app.puppetdb, 'current_version', return_value='4.2.0')
-    err = 'PuppetDB Version %d.%d.%d' % (4, 2, 0)
-    result = utils.get_db_version(app.puppetdb)
-    mock_info_log.assert_called_with(err)
-    assert (4, 0, 0) < result
-    assert (4, 2, 0) == result
-    assert (3, 2, 0) < result
-    assert (4, 3, 0) > result
-    assert (5, 0, 0) > result
-    assert (4, 2, 1) > result
+@pytest.mark.parametrize(
+    "version,is_ok",
+    [
+        ("4.2.0", False),
+        ("5.1.0", False),
+        ("5.2.0", True),
+        ("5.2.19", True),
+        ("6.4.0", True),
+        ("6.9.1", True),
+        ("7.0.0", True),
+        ("7.11.1-20220809_222149-g0b0b67c", True),
+        ("8.0.0", True),
+    ],
+)
+def test_db_version(mocker, version, is_ok):
+    mocker.patch.object(app.puppetdb, "current_version", return_value=version)
+    if is_ok:
+        utils.check_db_version(app.puppetdb)
+    else:
+        with pytest.raises(SystemExit) as e:
+            utils.check_db_version(app.puppetdb)
+            assert e.code == 1
 
 
 def test_db_invalid_version(mocker, mock_err_log):
     mocker.patch.object(app.puppetdb, 'current_version', return_value='4')
-    err = u"Unable to determine version from string: '%s'" % (4)
-    result = utils.get_db_version(app.puppetdb)
-    mock_err_log.assert_called_with(err)
-    assert (4, 0, 0) < result
-    assert (4, 2, 0) == result
+    with pytest.raises(SystemExit) as e:
+        utils.check_db_version(app.puppetdb)
+        assert e.code == 2
 
 
 def test_db_http_error(mocker, mock_err_log):
@@ -150,9 +187,9 @@ def test_db_http_error(mocker, mock_err_log):
 
     mocker.patch.object(app.puppetdb, 'current_version',
                         side_effect=raise_http_error)
-    result = utils.get_db_version(app.puppetdb)
-    mock_err_log.assert_called_with(err)
-    assert result == ()
+    with pytest.raises(SystemExit) as e:
+        utils.check_db_version(app.puppetdb)
+        assert e.code == 2
 
 
 def test_db_connection_error(mocker, mock_err_log):
@@ -166,9 +203,9 @@ def test_db_connection_error(mocker, mock_err_log):
 
     mocker.patch.object(app.puppetdb, 'current_version',
                         side_effect=connection_error)
-    result = utils.get_db_version(app.puppetdb)
-    mock_err_log.assert_called_with(err)
-    assert result == ()
+    with pytest.raises(SystemExit) as e:
+        utils.check_db_version(app.puppetdb)
+        assert e.code == 2
 
 
 def test_db_empty_response(mocker, mock_err_log):
@@ -179,17 +216,17 @@ def test_db_empty_response(mocker, mock_err_log):
 
     mocker.patch.object(app.puppetdb, 'current_version',
                         side_effect=connection_error)
-    result = utils.get_db_version(app.puppetdb)
-    mock_err_log.assert_called_with(err)
-    assert result == ()
+    with pytest.raises(SystemExit) as e:
+        utils.check_db_version(app.puppetdb)
+        assert e.code == 2
 
 
 def test_iter():
     test_list = (0, 1, 2, 3)
 
     def my_generator():
-        for i in test_list:
-            yield i
+        for element in test_list:
+            yield element
 
     gen = utils.yield_or_stop(my_generator())
     assert isinstance(gen, GeneratorType)
@@ -204,7 +241,6 @@ def test_stop_empty():
     def my_generator():
         yield 1
         raise EmptyResponseError
-        yield 2
 
     gen = utils.yield_or_stop(my_generator())
     for val in gen:
@@ -215,7 +251,6 @@ def test_stop_conn_error():
     def my_generator():
         yield 1
         raise ConnectionError
-        yield 2
 
     gen = utils.yield_or_stop(my_generator())
     for val in gen:
@@ -226,35 +261,12 @@ def test_stop_http_error():
     def my_generator():
         yield 1
         raise HTTPError
-        yield 2
 
     gen = utils.yield_or_stop(my_generator())
     for val in gen:
         assert 1 == val
 
 
-def test_is_bool_false():
-    test_values = [
-        "Test",
-        "SomeWrongData",
-        2,
-        2.0,
-        -5
-    ]
-
-    for test_value in test_values:
-        assert utils.is_bool(test_value) is False
-
-
-def test_is_bool_true():
-    test_values = [
-        "True",
-        "true",
-        "False",
-        "false",
-        "1",
-        "0"
-    ]
-
-    for test_value in test_values:
-        assert utils.is_bool(test_value) is True
+def test_quote_columns_data():
+    quoted_with_dot = utils.quote_columns_data('foo.bar')
+    assert quoted_with_dot == 'foo\\.bar'
